FL.objects.Canvas.Canvas
========================

.. currentmodule:: FL.objects.Canvas

.. autoclass:: Canvas
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Canvas.Convert
      ~Canvas.CurveTo
      ~Canvas.Ellipse
      ~Canvas.FillGlyph
      ~Canvas.FitGlyph
      ~Canvas.LineTo
      ~Canvas.MoveTo
      ~Canvas.OutlineGlyph
      ~Canvas.PutImage
      ~Canvas.Rectangle
      ~Canvas.SplineTo
      ~Canvas.TextOut
      ~Canvas.UnConvert
      ~Canvas.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Canvas.bk_color
      ~Canvas.bk_mode
      ~Canvas.brush_color
      ~Canvas.brush_style
      ~Canvas.delta
      ~Canvas.draw_style
      ~Canvas.parent
      ~Canvas.pen_color
      ~Canvas.pen_style
      ~Canvas.scale
      ~Canvas.text_color
   
   